############################################################################
############################################################################
############################################################################

package main;

no strict 'subs';
use Glib qw(TRUE FALSE);
use Gtk2 -init;

use CustomList;

sub fill_model {
	my $customlist = shift;

	my @firstnames = qw(Joe Jane William Hannibal Timothy Gargamel);
	my @surnames   = qw(Grokowich Twitch Borheimer Bork);

	foreach my $sname (@surnames) {
		foreach my $fname (@firstnames) {
			$customlist->append_record ("$fname $sname",
			                            1900 + rand (103.0))
		}
	}
}

sub create_view_and_model {
  my $customlist = CustomList->new;
  fill_model ($customlist);

  my $view = Gtk2::TreeView->new ($customlist);

  my $renderer = Gtk2::CellRendererText->new;
  my $col = Gtk2::TreeViewColumn->new;

  $col->pack_start ($renderer, TRUE);
  $col->add_attribute ($renderer, text => &CustomList::CUSTOM_LIST_COL_NAME);
  $col->set_title ("Name");
  $view->append_column ($col);
  $renderer->set (editable => TRUE);
  $renderer->signal_connect (edited => sub {
         my ($cell, $pathstring, $newtext, $model) = @_;
         my $path = Gtk2::TreePath->new_from_string ($pathstring);
         my $iter = $model->get_iter ($path);
         $model->set ($iter, &CustomList::CUSTOM_LIST_COL_NAME, $newtext);
  }, $customlist);

  $renderer = Gtk2::CellRendererText->new;
  $col = Gtk2::TreeViewColumn->new;
  $col->pack_start ($renderer, TRUE);
  $col->add_attribute ($renderer, text => &CustomList::CUSTOM_LIST_COL_YEAR_BORN);
  $col->set_title ("Year Born");
  $view->append_column ($col);

  return $view;
}

{
  my $window = Gtk2::Window->new;
  $window->set_default_size (200, 400);
  $window->signal_connect (delete_event => sub {Gtk2->main_quit; 0});

  my $vbox = Gtk2::VBox->new(0,0);
  $window->add ($vbox);

  my $view = create_view_and_model();
  my $scrollwin = Gtk2::ScrolledWindow->new;
  $scrollwin->add ($view);

  $vbox->pack_start($scrollwin, 1, 1, 0);  

  my $button = Gtk2::Button->new("Refresh");
  $button->signal_connect("clicked", sub { 
  	my $model = $view->get_model;
	$model->clear;
	
	fill_model($model);
  });
  $vbox->pack_start($button, 0, 0, 0);  

  $window->show_all;

  Gtk2->main;

  exit 0;
}


############################################################################
############################################################################
############################################################################
